# Protoc

These files were generated with protoc 3.19.4.

https://github.com/protocolbuffers/protobuf/releases/tag/v3.19.4

On macOS, you will need to approve the running of `protoc`.
This can be done by running `protoc`, approving the dialog box, then going
  to the **Privacy & Security** tab in the **Settings**. 
In the **Security** section, allow `protoc` to run. 
The next time you run `protoc`, you'll still  get a popup, but it will allow 
  the application to run.

## Generate a Python file

Change into the directory, of the repo, that contains the .proto files. 
You need to be in that directory because the `.proto` file 
  may include other `.proto` files.

```shell
/path/to/protoc-3.19.4-osx-x86_64/bin/protoc --python_out=.. FOO.proto
```
In the prior directory, `FOO_pb2.py` will be created. 
Move the file into the `keepercommander/proto` directory.

## Edit the file

Ignore `# Generated by the protocol buffer compiler.  DO NOT EDIT!` :)

You'll need change the import files to relative style imports. For example, change ....

```python
import enterprise_pb2 as enterprise_pb2
import record_pb2 as record_pb2
```

to 

```python
from . import enterprise_pb2 as enterprise_pb2
from . import record_pb2 as record_pb2
```